package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.checkPoint.CheckPointRecord;

import java.util.List;


/**
 * 巡更点记录Mapper接口
 * 
 * @author boman
 * @date 2025-02-14
 */
public interface CheckPointRecordMapper 
{
    /**
     * 查询巡更点记录
     * 
     * @param checkPointRecordId 巡更点记录主键
     * @return 巡更点记录
     */
    public CheckPointRecord selectCheckPointRecordByCheckPointRecordId(Long checkPointRecordId);

    /**
     * 查询巡更点记录列表
     * 
     * @param checkPointRecord 巡更点记录
     * @return 巡更点记录集合
     */
    public List<CheckPointRecord> selectCheckPointRecordList(CheckPointRecord checkPointRecord);

    /**
     * 新增巡更点记录
     * 
     * @param checkPointRecord 巡更点记录
     * @return 结果
     */
    public int insertCheckPointRecord(CheckPointRecord checkPointRecord);

    /**
     * 修改巡更点记录
     * 
     * @param checkPointRecord 巡更点记录
     * @return 结果
     */
    public int updateCheckPointRecord(CheckPointRecord checkPointRecord);

    /**
     * 删除巡更点记录
     * 
     * @param checkPointRecordId 巡更点记录主键
     * @return 结果
     */
    public int deleteCheckPointRecordByCheckPointRecordId(Long checkPointRecordId);

    /**
     * 批量删除巡更点记录
     * 
     * @param checkPointRecordIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCheckPointRecordByCheckPointRecordIds(Long[] checkPointRecordIds);
}
